.. _unit_test_report_rf6:

========================
Unit Test Report for rf6
========================

The log file that contains details about the executed test cases can be found `here <log.html>`_.

.. contents:: `Contents`
    :depth: 2
    :local:


Test Reports
============

.. item:: REPORT_UTEST-PI_LOOP_ASYMMETRIC_KI_COEFF Test report for UTEST-PI_LOOP_ASYMMETRIC_KI_COEFF
    :passes: UTEST-PI_LOOP_ASYMMETRIC_KI_COEFF
    :ext_robotframeworklog: log.html:s1-s1-t1

    Test result: Pass

.. item:: REPORT_UTEST-PI_LOOP_ASYMMETRIC_KP_COEFF Test report for UTEST-PI_LOOP_ASYMMETRIC_KP_COEFF
    :passes: UTEST-PI_LOOP_ASYMMETRIC_KP_COEFF
    :ext_robotframeworklog: log.html:s1-s1-t2

    Test result: Pass

Traceability Matrix
===================

The below table traces the test report to test cases.

.. item-matrix:: Linking these unit test reports to unit test cases
    :source: REPORT_UTEST-
    :target: UTEST-
    :sourcetitle: Unit test report
    :targettitle: Unit test specification
    :type: fails passes skipped
    :stats:
    :group: top
    :nocaptions:
